@@ -11,10 +11,10 @@ use strict;
 use warnings;
 
 package Dist::Zilla::PluginBundle::Author::RWSTAUNER;
-# git description: v4.203-7-g5afccdb
+# git description: v4.204-3-g114a6b3
 
 our $AUTHORITY = 'cpan:RWSTAUNER';
-$Dist::Zilla::PluginBundle::Author::RWSTAUNER::VERSION = '4.204';
+$Dist::Zilla::PluginBundle::Author::RWSTAUNER::VERSION = '4.205';
 # ABSTRACT: RWSTAUNER's Dist::Zilla config
 
 use Moose;
@@ -259,8 +259,8 @@ sub configure {
 
   # gather and prune
     $self->_generate_manifest_skip,
+    [ GatherDir => { exclude_filename => [ @{ $self->copy_files } ] } ],
     qw(
-      GatherDir
       PruneCruft
       ManifestSkip
     ),
@@ -327,7 +327,7 @@ sub configure {
         phase      => 'release',
       }
     ],
-    [ CopyFilesFromRelease => { filename => $self->copy_files } ],
+    [ CopyFilesFromRelease => { filename => [ @{ $self->copy_files } ] } ],
 
   # metadata
     [
@@ -549,7 +549,7 @@ Dist::Zilla::PluginBundle::Author::RWSTAUNER - RWSTAUNER's Dist::Zilla config
 
 =head1 VERSION
 
-version 4.204
+version 4.205
 
 =head1 SYNOPSIS
 
@@ -642,6 +642,8 @@ This bundle is roughly equivalent to the following (generated) F<dist.ini>:
   is_template = 1
 
   [GatherDir]
+  exclude_filename = LICENSE
+
   [PruneCruft]
   [ManifestSkip]
 
